==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/azurestackhci/kotlin/inputs/GetArcSettingPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.azurestackhci.kotlin.inputs

import com.pulumi.azurenative.azurestackhci.inputs.GetArcSettingPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property arcSettingName The name of the proxy resource holding details of HCI ArcSetting information.
 * @property clusterName The name of the cluster.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 */
public data class GetArcSettingPlainArgs(
    public val arcSettingName: String,
    public val clusterName: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.azurestackhci.inputs.GetArcSettingPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.azurestackhci.inputs.GetArcSettingPlainArgs =
        com.pulumi.azurenative.azurestackhci.inputs.GetArcSettingPlainArgs.builder()
            .arcSettingName(arcSettingName.let({ args0 -> args0 }))
            .clusterName(clusterName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetArcSettingPlainArgs].
 */
@PulumiTagMarker
public class GetArcSettingPlainArgsBuilder internal constructor() {
    private var arcSettingName: String? = null

    private var clusterName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The name of the proxy resource holding details of HCI ArcSetting information.
     */
    @JvmName("padjubtcxvcnosoq")
    public suspend fun arcSettingName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.arcSettingName = mapped
    }

    /**
     * @param value The name of the cluster.
     */
    @JvmName("ujxtbpfpjjnklaqb")
    public suspend fun clusterName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.clusterName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("ciifpxocmhjlkfft")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetArcSettingPlainArgs = GetArcSettingPlainArgs(
        arcSettingName = arcSettingName ?: throw PulumiNullFieldException("arcSettingName"),
        clusterName = clusterName ?: throw PulumiNullFieldException("clusterName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/azurestackhci/kotlin/inputs/GetArcSettingPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.azurestackhci.kotlin.inputs

import com.pulumi.azurenative.azurestackhci.inputs.GetArcSettingPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property arcSettingName The name of the proxy resource holding details of HCI ArcSetting information.
 * @property clusterName The name of the cluster.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 */
public data class GetArcSettingPlainArgs(
    public val arcSettingName: String,
    public val clusterName: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.azurestackhci.inputs.GetArcSettingPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.azurestackhci.inputs.GetArcSettingPlainArgs =
        com.pulumi.azurenative.azurestackhci.inputs.GetArcSettingPlainArgs.builder()
            .arcSettingName(arcSettingName.let({ args0 -> args0 }))
            .clusterName(clusterName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetArcSettingPlainArgs].
 */
@PulumiTagMarker
public class GetArcSettingPlainArgsBuilder internal constructor() {
    private var arcSettingName: String? = null

    private var clusterName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The name of the proxy resource holding details of HCI ArcSetting information.
     */
    @JvmName("ixwlfnntmavtrlhp")
    public suspend fun arcSettingName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.arcSettingName = mapped
    }

    /**
     * @param value The name of the cluster.
     */
    @JvmName("mqcljjlwfmleooni")
    public suspend fun clusterName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.clusterName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("dtjronmdawofkqnv")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetArcSettingPlainArgs = GetArcSettingPlainArgs(
        arcSettingName = arcSettingName ?: throw PulumiNullFieldException("arcSettingName"),
        clusterName = clusterName ?: throw PulumiNullFieldException("clusterName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}
